.. acoustics documentation master file, created by
   sphinx-quickstart on Fri Aug 16 09:40:59 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation of the acoustics module!
=====================================================




Contents:


.. toctree::
   :maxdepth: 1
   
   reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

